<?php
/**
 * Content classes for themes primary tags.
 *
 * @since 0.1.17
 *
 */

class UBC_CLF_Html_Classes {

	/**
	 * Set up filter hooks for main html tag classes
	 *
	 * @since 1.0.0
	 *
	 */
	public function init() {

		add_filter( 'wp_clf_lite_root_content_classes', array( $this, 'wp_clf_lite_root_content_classes_off_canvas_content' ), 10, 2 );
		add_filter( 'wp_clf_lite_widget_area_classes', array( $this, 'wp_clf_lite_secondary_content_classes_off_canvas_content' ), 10, 2 );
		add_filter( 'body_class', array( $this, 'wp_clf_lite_add_body_classes_featured_custom_image' ), 10, 1 );
		add_filter( 'body_class', array( $this, 'wp_clf_lite_add_body_classes_get_option_show_on_front_sections' ), 10, 1 );
		add_filter( 'body_class', array( $this, 'wp_clf_lite_add_body_class_theme_scheme_options' ), 10, 1 );

	}

	/**
	 * Add off-canvas-content to #content
	 * #content content area
	 * root_content_classes() method in WP_CLF_Lite_Content_Classes
	 *
	 * @since 0.1.11
	 *
	 * @param(array) $classes - Pre-existing classes for this Tag
	 * @param(string) The additional comma-separated list of classes passed
	 * @return (array) The modified array of classes
	 */
	public function wp_clf_lite_root_content_classes_off_canvas_content( $classes ) {

		$classes[] = 'off-canvas-content';

			return $classes;

	}/* wp_clf_lite_root_content_classes_off_canvas_content() */

	/**
	 * Add off-canvas position-left reveal-for-large to #secondary
	 * #secondary
	 * root_content_classes() method in WP_CLF_Lite_Content_Classes
	 *
	 * @since 0.1.17
	 *
	 * @param(array) $classes - Pre-existing classes for this Tag
	 * @param(string) The additional comma-separated list of classes passed
	 * @return (array) The modified array of classes
	 */
	public function wp_clf_lite_secondary_content_classes_off_canvas_content( $classes ) {

		$classes[] = 'off-canvas position-left reveal-for-large sidebar main-sidebar';

			return $classes;

	}/* wp_clf_lite_secondary_content_classes_off_canvas_content() */


	/**
	 * Add body class on frontpage/home if post type has featured or custom header image
	 * body
	 * root_content_classes() method in WP_CLF_Lite_Content_Classes
	 *
	 * @since 0.1.11
	 *
	 * @param(array) $classes - Pre-existing classes for this Tag
	 * @param(string) The additional comma-separated list of classes passed
	 * @return (array) The modified array of classes
	 */
	public function wp_clf_lite_add_body_classes_featured_custom_image( $classes ) {

		if ( has_post_thumbnail() ||  has_header_image() ) :

			$classes[] = 'has-banner-image';

		endif;

			return $classes;

	}/* wp_clf_lite_add_body_classes_featured_custom_image() */

	/**
	 * Add body class if get_option( 'show_on_front' ) equals sections.
	 * body
	 * root_content_classes() method in WP_CLF_Lite_Content_Classes
	 *
	 * @since 0.1.16
	 *
	 * @param(array) $classes - Pre-existing classes for this Tag
	 * @param(string) The additional comma-separated list of classes passed
	 * @return (array) The modified array of classes
	 */
	public function wp_clf_lite_add_body_classes_get_option_show_on_front_sections( $classes ) {

		$get_option_show_on_front = get_option( 'show_on_front' );

		if ( 'sections' === $get_option_show_on_front && is_home() ) :

			$classes[] = 'home with-sections';

		endif;

			return $classes;

	}/* wp_clf_lite_add_body_classes_get_option_show_on_front_sections */


	/**
	 * Add body class based on get theme mod ubc_clf_lite_theme_select_section.
	 * body
	 *
	 * @since 0.1.18
	 *
	 * @param(array) $classes - Pre-existing classes for this Tag
	 * @param(string) The additional comma-separated list of classes passed
	 * @return (array) The modified array of classes
	 */

	public function wp_clf_lite_add_body_class_theme_scheme_options( $classes ) {

		$get_theme_mode = ! empty( get_theme_mod( 'ubc_clf_lite_theme_select_section' ) ) ? get_theme_mod( 'ubc_clf_lite_theme_select_section' ) : 'default-theme';

		$classes[] = esc_attr( $get_theme_mode );

			return $classes;

	}/* wp_clf_lite_add_body_class_theme_scheme_options() */

}

// Initialize our child theme changes.
add_action( 'after_setup_theme', 'after_setup_theme_ubc_clf_lite_content_classes_hooks_init', 15 );


/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme_ubc_clf_lite_content_classes_hooks_init() {

	$UBC_CLF_Html_Classes = new UBC_CLF_Html_Classes();
	$UBC_CLF_Html_Classes->init();

}/* after_setup_theme_ubc_clf_lite_content_classes_hooks_init() */
