<?php

/**
 * Theme Hook Alliance hook
 *
 * @since 1.0.0
 *
 */

class UBC_CLF_Lite_Tha_Hooks {

	/**
	 * Set up our tha hooks
	 *
	 * @since 1.0.0
	 *
	 */
	public function init() {

		// Custom header part.
		add_action( 'tha_head_top', array( $this, 'add_ubc_wp_clf_lite_custom_theme_color_switch' ), 10, 2 );

		add_action( 'tha_header_bottom', array( $this, 'add_ubc_wp_clf_lite_custom_header' ), 10, 2 );

		// Off-canvas main menu.
		add_action( 'tha_header_after', array( $this, 'add_off_canvas_main_menu_tha_header_after' ), 10, 2 );

		// Custom sidebar setup.
		add_action( 'tha_sidebar_top', array( $this, 'add_ubc_wp_clf_lite_sidebar_title_header' ), 10, 2 );

		// Add banner to content.
		add_action( 'tha_content_top', array( $this, 'add_banner_image_before_primary_content' ), 10, 2 );

		// Offcavas main sidebar.
		// add_action( 'tha_content_after', array( $this, 'add_add_off_canvas_sidebar_after_content' ), 10, 2 );

		// Offcavas for notifications or feedback.
		add_action( 'tha_footer_before', array( $this, 'add_feedback_notification_box' ), 10, 2 );

		// Footer content.
		add_action( 'tha_footer_top', array( $this, 'add_footer_content_tha_footer_top' ), 10, 2 );

		// Svg sprite template.
		add_action( 'tha_body_bottom', array( $this, 'add_svg_sprite_tha_footer_top' ), 10, 2 );

		add_action( 'tha_body_bottom', array( $this, 'off_canvas_wrapper_closing' ), 10, 2 );

		add_action( 'tha_body_top', array( $this, 'off_canvas_wrapper_opening' ), 10, 2 );

		// home and course content buttons.
		add_action( 'tha_sidebars_before', array( $this, 'ubc_wp_clf_lite_add_home_course_content_buttons' ), 10, 2 );

	}/* init() */


	/**
	 * Template for sidebar using tha_sidebar_top()
	 *
	 * @since 0.0.18
	 */
	public function add_ubc_wp_clf_lite_custom_theme_color_switch() {

		echo '<style>';

			get_template_part( 'template-parts/top-head-css' );

		echo '</style>';

		if ( isset( $_COOKIE['fullCSS'] ) && 'true' === $_COOKIE['fullCSS'] ) :

			echo '<script>';
			get_template_part( 'template-parts/load-css-js' );
			echo '</script>';

		else :

			echo '<script>';
			get_template_part( 'template-parts/load-css-js' );
			get_template_part( 'template-parts/load-onloadcss-js' );
			echo '</script>';

		endif;

	}

	/**
	 * Template for sidebar using tha_sidebar_top()
	 *
	 * @since 1.0.0
	 */
	public function add_ubc_wp_clf_lite_sidebar_title_header() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/custom-sidebar.php' );

	} /* add_ubc_wp_clf_lite_sidebar_title_header() */


	/**
	 * Template for off-canvas main menu content using tha_header_after()
	 *
	 * @since 0.1.9
	 */
	public function add_off_canvas_main_menu_tha_header_after() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-main-menu.php' );

	} /* add_ubc_wp_clf_lite_sidebar_title_header() */

	/**
	 * Template for custom header part using tha_header_top()
	 *
	 * @since 1.0.0
	 */
	public function add_ubc_wp_clf_lite_custom_header() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/custom-header-part.php' );

	} /* add_ubc_wp_clf_lite_custom_header() */


	/**
	 * Template for custom header part using tha_primary_content()
	 *
	 * @since 1.0.0
	 */
	public function add_banner_image_before_primary_content() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-banner-img.php' );

	} /* add_banner_image_before_primary_content() */

	/**
	 * Template for feedback off canvas window for notifications or feedback using tha_footer_before()
	 *
	 * @since 0.1.6
	 */
	public function add_feedback_notification_box() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-feedback.php' );

	} /* add_feedback_notification_box() */

	/**
	 * Template for sidebar off canvas window using tha_content_after()
	 *
	 * @since 0.1.9
	 */
	public function add_add_off_canvas_sidebar_after_content() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-main-sidebar.php' );

	} /* add_add_off_canvas_sidebar_after_content() */

	/**
	 * Template for footer content using tha_footer_top()
	 *
	 * @since 0.1.9
	 */
	public function add_footer_content_tha_footer_top() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-footer-top.php' );

	} /* add_footer_content_tha_footer_top() */

	/**
	 * Template for svg footer content using tha_body_bottom()
	 *
	 * @since 0.1.9
	 */
	public function add_svg_sprite_tha_footer_top() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/svg-sprite.php' );

	} /* add_svg_sprite_tha_footer_top() */

	/**
	 * insert div container for off canvas wrapper opening
	 *
	 * @since 0.1.9
	 */
	public function off_canvas_wrapper_opening() {

		echo '<div class="off-canvas-wrapper">';

	} /* off_canvas_wrapper_opening() */

	/**
	 * insert div container for off canvas wrapper opening
	 *
	 * @since 0.1.9
	 */
	public function off_canvas_wrapper_closing() {

		echo '</div>';

	} /* off_canvas_wrapper_closing() */

	/**
	 * Call template for home and course content buttons tha_sidebars_before()
	 *
	 * @since 0.1.9
	 */
	public function ubc_wp_clf_lite_add_home_course_content_buttons() {

		$startPath = trailingslashit( dirname( __FILE__ ) ) . '../template-parts';
		$dashboard_menu_templ = 'home-course-content-buttons.php';

		\UBC\Helpers::locate_template_part_in_plugin( $startPath, $dashboard_menu_templ, true, false );

	} /* add_svg_sprite_tha_footer_top() */

}

// Initialize our child theme changes.
add_action( 'after_setup_theme', 'after_setup_theme_ubc_clf_lite_tha_hooks_init', 15 );


/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme_ubc_clf_lite_tha_hooks_init() {

	$UBC_CLF_Lite_Tha_Hooks = new UBC_CLF_Lite_Tha_Hooks();
	$UBC_CLF_Lite_Tha_Hooks->init();

}/* after_setup_theme_ubc_clf_lite_tha_hooks_init() */
