<?php
/**
 * Template for section page listings
 * loadd by course_sidebar_sections_list_sections ()  functions.php
 *
 * @author David Brabbins
 * @since 1.0
 * @package WordPress
 */

// Global varible created course_sidebar_sections_list_sections () functions.php.
$the_id = get_the_ID();
// Filter to short-circuit display of this item
$display = apply_filters( 'wp_clf_lite_display_course_section_list_item', null, $the_id );
// Checking to see if mark as completed is set to be used
$show_mark_complete_btn = \UBC\Press\Utils::do_components_show_mark_as_complete();


if ( null !== $display ) {
	return;
}

// Setup some varible for the loop.
$the_title 		= get_the_title();
$the_permalink	= get_the_permalink();


// Find out the number of completed components for this section. @TODO: AJAX call?
$completed_comps_data		= \UBC\Press\Utils::completed_components_for_section( $the_id );

// $completed_comps_data will contain ['completed_components'] and 'total_components'
$num_total_components		= $completed_comps_data['total_components'];
$num_completed_components	= count( $completed_comps_data['completed_components'] );

// Find the percentage for completed components complete / total * 100. Assume 100 when no completable.
$num_percentage				= ( 0 === $num_total_components || null === $num_total_components ) ? 100 : ( ($num_completed_components / $num_total_components) * 100 );

// Set class for 100% complete.
$numb_total_complete		= ( 100 === $num_percentage ) ? 'completed' : '';

// Set class for when complete components is zero or another class when progress has started.
$no_complete_components 	= ( 0 === $num_completed_components ) ? 'no-complete' : 'start-progress';


$completed_text = sprintf( __( '%1$sCompleted: %2$s%3$s/%4$s', \UBC\Press::get_text_domain() ),
	'<span class="completed-text">',
	'</span>',
	'<span class="completed-components">' . absint( $num_completed_components ) . '</span>',
	'<span class="total-components">' . absint( $num_total_components ) . '</span>'
);

$no_completable_components_text = __( 'None to complete', 'ubc-wp-clf-lite' );

$comp_text_to_output = ( $num_total_components > 0 ) ? $completed_text : $no_completable_components_text;

// Class for section listing: .current_page_item or .page_item.
global $wp_query;
$the_post_id = $wp_query->post->ID;

$section_list_class = ( $the_post_id === $the_id ) ? 'current-page-item' : '';

// // Saved icon.
// $icon_to_use = ( ! empty( get_post_meta( $the_id, '_section_icon', true ) ) ) ? get_post_meta( $the_id, '_section_icon', true ) : 'dashicons-portfolio';

?>
<li class="align-items-center <?php echo esc_html( $section_list_class ); ?> sub-section-<?php echo esc_html( $the_id ); ?>" data-post-id="<?php echo absint( $the_id ); ?>">
	<a href="<?php echo esc_url( $the_permalink ); ?>" title="<?php the_title_attribute( array( 'before' => 'Read more on ', 'after' => wp_kses_post( $comp_text_to_output ) ) ); ?>" class="sub-section-link row">
		<?php if ( is_user_logged_in() && ! empty( $show_mark_complete_btn ) ) : ?>

			<span class="completed-components-details show-for-sr"><small>[<?php echo wp_kses_post( $comp_text_to_output ); ?>]</small></span>

			<?php if ( $num_total_components > 0 ) : ?>

			<div aria-hidden="true" class="progress <?php echo esc_html( $numb_total_complete ); ?> <?php echo esc_html( $no_complete_components ); ?>" role="progressbar" tabindex="0" aria-valuenow="<?php echo absint( $num_percentage ); ?>" aria-valuemin="0" aria-valuetext="<?php echo absint( $num_percentage ); ?> percent"  aria-valuemax="100">
				<div class="progress-meter" style="width: <?php echo absint( $num_percentage ); ?>%">
				</div>
				<p class="progress-meter-text"><span class="show-for-sr"><?php echo absint( $num_percentage ); ?>%</span> <svg class="ui-icon" aria-hidden="true"><use xlink:href="#checkmark-circle"></use></svg></p>
			</div>

		<?php else: ?>

			<span class="forum-icon">
				<svg class="ui-icon discussions" aria-hidden="true"><use xlink:href="#discussions"></use></svg>
			</span>

			<?php endif; ?>



		<?php endif; ?>
		<h4 class="sub-section-title">
			<?php  echo esc_html( $the_title ); ?>
		</h4>
	</a>

</li>
